@@ -1,12 +1,13 @@
 package Catalyst::Engine::Stomp;
 use Moose;
-extends 'Catalyst::Engine::Embeddable';
-
-our $VERSION = '0.04';
-
 use List::MoreUtils qw/ uniq /;
 use HTTP::Request;
 use Net::Stomp;
+use namespace::autoclean;
+
+extends 'Catalyst::Engine::Embeddable';
+
+our $VERSION = '0.05';
 
 has connection => (is => 'rw', isa => 'Net::Stomp');
 has conn_desc => (is => 'rw', isa => 'Str');
@@ -22,7 +23,7 @@ Catalyst::Engine::Stomp - write message handling apps with Catalyst.
   BEGIN {
     $ENV{CATALYST_ENGINE} = 'Stomp';
     require Catalyst::Engine::Stomp;
-  }  
+  }
 
   MyApp->config->{Engine::Stomp} =
    {
@@ -46,7 +47,7 @@ Catalyst::Engine::Stomp - write message handling apps with Catalyst.
 =head1 DESCRIPTION
 
 Write a Catalyst app connected to a Stomp messagebroker, not HTTP. You
-need a controller that understands messaging, as well as this engine. 
+need a controller that understands messaging, as well as this engine.
 
 This is single-threaded and single process - you need to run multiple
 instances of this engine to get concurrency, and configure your broker
@@ -54,8 +55,8 @@ to load-balance across multiple consumers of the same queue.
 
 Controllers are mapped to Stomp queues, and a controller base class is
 provided, Catalyst::Controller::MessageDriven, which implements
-YAML-serialized messages, mapping a top-level YAML "type" key to 
-the action. 
+YAML-serialized messages, mapping a top-level YAML "type" key to
+the action.
 
 =head1 METHODS
 
@@ -95,8 +96,8 @@ sub run {
         foreach my $queue (@queues) {
                 my $queue_name = "/queue/$queue";
                 $self->connection->subscribe({
-                                              destination => $queue_name, 
-                                              ack         => 'client' 
+                                              destination => $queue_name,
+                                              ack         => 'client'
                                              });
         }
 
@@ -117,10 +118,10 @@ client IP address.
 =cut
 
 sub prepare_request {
-        my ($self, $c, $req, $res_ref) = @_;
-        shift @_;
-        $self->next::method(@_);
-        $c->req->address($self->conn_desc);
+    my ($self, $c, $req, $res_ref) = @_;
+    shift @_;
+    $self->next::method(@_);
+    $c->req->address($self->conn_desc);
 }
 
 =head2 finalize_headers
@@ -131,12 +132,12 @@ Overridden to dump out any errors encountered, since you won't get a
 =cut
 
 sub finalize_headers {
-        my ($self, $c) = @_;
-        my $error = join "\n", @{$c->error};
-        if ($error) {
-                $c->log->debug($error);
-        }
-        return $self->next::method($c);
+    my ($self, $c) = @_;
+    my $error = join "\n", @{$c->error};
+    if ($error) {
+        $c->log->debug($error);
+    }
+    return $self->next::method($c);
 }
 
 =head2 handle_stomp_frame
@@ -146,18 +147,18 @@ Dispatch according to Stomp frame type.
 =cut
 
 sub handle_stomp_frame {
-        my ($self, $app, $frame) = @_;
+    my ($self, $app, $frame) = @_;
 
-        my $command = $frame->command();
-        if ($command eq 'MESSAGE') {
-                $self->handle_stomp_message($app, $frame);
-        }
-        elsif ($command eq 'ERROR') {
-                $self->handle_stomp_error($app, $frame);
-        }
-        else {
-                $app->log->debug("Got unknown Stomp command: $command");
-        }
+    my $command = $frame->command();
+    if ($command eq 'MESSAGE') {
+        $self->handle_stomp_message($app, $frame);
+    }
+    elsif ($command eq 'ERROR') {
+        $self->handle_stomp_error($app, $frame);
+    }
+    else {
+        $app->log->debug("Got unknown Stomp command: $command");
+    }
 }
 
 =head2 handle_stomp_message
@@ -167,31 +168,31 @@ Dispatch a Stomp message into the Catalyst app.
 =cut
 
 sub handle_stomp_message {
-        my ($self, $app, $frame) = @_;
+    my ($self, $app, $frame) = @_;
 
-        # queue -> controller
-        my $queue = $frame->headers->{destination};
-        my ($controller) = $queue =~ m!^/queue/(.*)$!;
+    # queue -> controller
+    my $queue = $frame->headers->{destination};
+    my ($controller) = $queue =~ m|^/queue/(.*)$|;
 
-        # set up request
-        my $config = $app->config->{'Engine::Stomp'};
-        my $url = 'stomp://'.$config->{hostname}.':'.$config->{port}.'/'.$controller;
-        my $req = HTTP::Request->new(POST => $url);
-        $req->content($frame->body);
-        $req->content_length(length $frame->body);
+    # set up request
+    my $config = $app->config->{'Engine::Stomp'};
+    my $url = 'stomp://'.$config->{hostname}.':'.$config->{port}.'/'.$controller;
+    my $req = HTTP::Request->new(POST => $url);
+    $req->content($frame->body);
+    $req->content_length(length $frame->body);
 
-        # dispatch
-        my $response;
-        $app->handle_request($req, \$response);
+    # dispatch
+    my $response;
+    $app->handle_request($req, \$response);
 
-        # reply, if header set
-        if (my $reply_to = $response->headers->header('X-Reply-Address')) {
-                my $reply_queue = '/remote-temp-queue/' . $reply_to;
-                $self->connection->send({ destination => $reply_queue, body => $response->content });
-        }
+    # reply, if header set
+    if (my $reply_to = $response->headers->header('X-Reply-Address')) {
+        my $reply_queue = '/remote-temp-queue/' . $reply_to;
+        $self->connection->send({ destination => $reply_queue, body => $response->content });
+    }
 
-        # ack the message off the queue now we've replied / processed
-        $self->connection->ack( { frame => $frame } );
+    # ack the message off the queue now we've replied / processed
+    $self->connection->ack( { frame => $frame } );
 }
 
 =head2 handle_stomp_error
@@ -201,13 +202,11 @@ Log any Stomp error frames we receive.
 =cut
 
 sub handle_stomp_error {
-        my ($self, $app, $frame) = @_;
-        
-        my $error = $frame->headers->{message};
-        $app->log->debug("Got Stomp error: $error");
+    my ($self, $app, $frame) = @_;
+
+    my $error = $frame->headers->{message};
+    $app->log->debug("Got Stomp error: $error");
 }
 
 __PACKAGE__->meta->make_immutable;
 
-1;
-
